@@ -4,46 +4,65 @@ build_time_vars = {'ABIFLAGS': 'm',
  'AIX_GENUINE_CPLUSPLUS': 0,
  'AR': 'ar',
  'ARFLAGS': 'rc',
- 'ASDLGEN': '@echo python: not-found! cannot run ./Parser/asdl_c.py # ./Parser/asdl_c.py',
+ 'ASDLGEN': '@echo python: not-found! cannot run ./Parser/asdl_c.py # '
+            './Parser/asdl_c.py',
  'ASDLGEN_FILES': './Parser/asdl.py ./Parser/asdl_c.py',
  'AST_ASDL': './Parser/Python.asdl',
  'AST_C': 'Python/Python-ast.c',
  'AST_C_DIR': 'Python',
  'AST_H': 'Include/Python-ast.h',
  'AST_H_DIR': 'Include',
- 'BASECFLAGS': '-fno-strict-aliasing',
+ 'BASECFLAGS': '-fno-strict-aliasing -Werror=declaration-after-statement',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/local/bin',
- 'BINLIBDEST': '/usr/local/lib/python3.3',
- 'BLDLIBRARY': '-L. -lpython3.3m',
- 'BLDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ -L/usr/obj/ports/Python-3.3.5/Python-3.3.5',
+ 'BINLIBDEST': '/usr/local/lib/python3.4',
+ 'BLDLIBRARY': '-L. -lpython3.4m',
+ 'BLDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
+              '-L/usr/obj/ports/Python-3.4.1/Python-3.4.1',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'mips64-unknown-openbsd5.6',
+ 'BUILD_GNU_TYPE': 'powerpc-unknown-openbsd5.6',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -DNDEBUG -O2 -pipe  -fPIC -O2 -pipe -O2 -pipe',
+ 'CFLAGS': '-fno-strict-aliasing -Werror=declaration-after-statement '
+           '-DNDEBUG -O2 -pipe  -fPIC -O2 -pipe -O2 -pipe',
  'CFLAGSFORSHARED': '-fPIC',
- 'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
+ 'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
+                'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-O2 -pipe',
  'CONFIGURE_CPPFLAGS': '-I/usr/local/include',
  'CONFIGURE_LDFLAGS': '-L/usr/local/lib/',
- 'CONFIG_ARGS': "'--enable-shared' '--srcdir=/usr/obj/ports/Python-3.3.5/Python-3.3.5' '--with-fpectl' '--with-threads' '--enable-ipv6' '--with-cxx_main' '--with-system-expat' '--with-system-ffi' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
+ 'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-shared' "
+                "'--srcdir=/usr/obj/ports/Python-3.4.1/Python-3.4.1' "
+                "'--with-fpectl' '--with-threads' '--enable-ipv6' "
+                "'--with-cxx_main' '--with-system-expat' '--with-system-ffi' "
+                "'--prefix=/usr/local' '--sysconfdir=/etc' "
+                "'--mandir=/usr/local/man' '--infodir=/usr/local/info' "
+                "'--localstatedir=/var' '--disable-silent-rules' 'CC=cc' "
+                "'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' "
+                "'CPPFLAGS=-I/usr/local/include'",
  'CONFINCLUDEDIR': '/usr/local/include',
- 'CONFINCLUDEPY': '/usr/local/include/python3.3m',
+ 'CONFINCLUDEPY': '/usr/local/include/python3.4m',
  'COREPYTHONPATH': ':plat-openbsd5',
+ 'COVERAGE_INFO': '/usr/obj/ports/Python-3.4.1/Python-3.4.1/coverage.info',
+ 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.4.1/Python-3.4.1/lcov-report',
+ 'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
+                            'report"',
  'CPPFLAGS': '-I. -IInclude -I./Include -I/usr/local/include',
  'CXX': 'c++ -pthread',
- 'DESTDIRS': '/usr/local /usr/local/lib /usr/local/lib/python3.3 /usr/local/lib/python3.3/lib-dynload',
- 'DESTLIB': '/usr/local/lib/python3.3',
+ 'DESTDIRS': '/usr/local /usr/local/lib /usr/local/lib/python3.4 '
+             '/usr/local/lib/python3.4/lib-dynload',
+ 'DESTLIB': '/usr/local/lib/python3.4',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/local/lib/python3.3/lib-dynload',
+ 'DESTSHARED': '/usr/local/lib/python3.4/lib-dynload',
  'DIRMODE': 755,
- 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in Include Lib Misc Ext-dummy',
+ 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
+         'Makefile.pre.in Include Lib Misc Ext-dummy',
  'DISTDIRS': 'Include Lib Misc Ext-dummy',
- 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
+ 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h '
+              'pyconfig.h.in Makefile.pre.in',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
@@ -51,6 +70,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 0,
  'DYNLOADFILE': 'dynload_shlib.o',
  'ENABLE_IPV6': 1,
+ 'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
  'EXTRAMACHDEPPATH': '',
@@ -70,12 +90,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
+ 'HAVE_ALIGNED_REQUIRED': 0,
  'HAVE_ALLOCA_H': 0,
  'HAVE_ALTZONE': 0,
  'HAVE_ASINH': 1,
  'HAVE_ASM_TYPES_H': 0,
  'HAVE_ATANH': 1,
- 'HAVE_ATTRIBUTE_FORMAT_PARSETUPLE': 0,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
  'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
@@ -117,7 +137,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_DLFCN_H': 1,
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
+ 'HAVE_DUP3': 0,
  'HAVE_DYNAMIC_LOADING': 1,
+ 'HAVE_ENDIAN_H': 1,
  'HAVE_EPOLL': 0,
  'HAVE_EPOLL_CREATE1': 0,
  'HAVE_ERF': 1,
@@ -156,9 +178,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GAMMA': 1,
  'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 0,
- 'HAVE_GCC_UINT128_T': 1,
+ 'HAVE_GCC_UINT128_T': 0,
  'HAVE_GETADDRINFO': 1,
- 'HAVE_GETCWD': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETGROUPLIST': 1,
  'HAVE_GETGROUPS': 1,
@@ -188,6 +209,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
  'HAVE_HSTRERROR': 1,
+ 'HAVE_HTOLE64': 0,
  'HAVE_HYPOT': 1,
  'HAVE_IEEEFP_H': 1,
  'HAVE_IF_NAMEINDEX': 1,
@@ -203,7 +225,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 0,
+ 'HAVE_LARGEFILE_SUPPORT': 1,
  'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
@@ -218,6 +240,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LIBUTIL_H': 0,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_CAN_BCM_H': 0,
  'HAVE_LINUX_CAN_H': 0,
  'HAVE_LINUX_CAN_RAW_H': 0,
  'HAVE_LINUX_NETLINK_H': 0,
@@ -259,6 +282,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_POSIX_FADVISE': 0,
  'HAVE_POSIX_FALLOCATE': 0,
  'HAVE_PREAD': 1,
+ 'HAVE_PRLIMIT': 0,
  'HAVE_PROCESS_H': 0,
  'HAVE_PROTOTYPES': 1,
  'HAVE_PTHREAD_ATFORK': 1,
@@ -357,6 +381,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SYS_BSDTTY_H': 0,
  'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
+ 'HAVE_SYS_ENDIAN_H': 1,
  'HAVE_SYS_EPOLL_H': 0,
  'HAVE_SYS_EVENT_H': 1,
  'HAVE_SYS_FILE_H': 1,
@@ -421,6 +446,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_WCSCOLL': 1,
  'HAVE_WCSFTIME': 1,
  'HAVE_WCSXFRM': 1,
+ 'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
@@ -428,41 +454,45 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HGBRANCH': '',
  'HGTAG': '',
  'HGVERSION': '',
- 'HOST_GNU_TYPE': 'mips64-unknown-openbsd5.6',
- 'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include /usr/local/include/python3.3m /usr/local/include/python3.3m',
+ 'HOST_GNU_TYPE': 'powerpc-unknown-openbsd5.6',
+ 'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
+                   '/usr/local/include/python3.4m '
+                   '/usr/local/include/python3.4m',
  'INCLUDEDIR': '/usr/local/include',
- 'INCLUDEPY': '/usr/local/include/python3.3m',
+ 'INCLUDEPY': '/usr/local/include/python3.4m',
  'INSTALL': '/usr/bin/install -c -o root -g bin',
  'INSTALL_DATA': 'install -c -o root -g bin -m 444',
  'INSTALL_PROGRAM': 'install -c -s -o root -g bin -m 555',
  'INSTALL_SCRIPT': 'install -c -o root -g bin -m 555',
  'INSTALL_SHARED': '/usr/bin/install -c -o root -g bin -m 555',
- 'INSTSONAME': 'libpython3.3m.so.0.0',
+ 'INSTSONAME': 'libpython3.4m.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'c++ -pthread -shared -fPIC',
- 'LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.3.5/Python-3.3.5',
+ 'LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.4.1/Python-3.4.1',
  'LDLAST': '',
- 'LDLIBRARY': 'libpython3.3m.so',
+ 'LDLIBRARY': 'libpython3.4m.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ -L/usr/obj/ports/Python-3.3.5/Python-3.3.5',
- 'LDVERSION': '3.3m',
+ 'LDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
+             '-L/usr/obj/ports/Python-3.4.1/Python-3.4.1',
+ 'LDVERSION': '3.4m',
  'LIBC': '',
- 'LIBDEST': '/usr/local/lib/python3.3',
+ 'LIBDEST': '/usr/local/lib/python3.4',
  'LIBDIR': '/usr/local/lib',
  'LIBFFI_INCLUDEDIR': '/usr/local/include',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/local/lib/pkgconfig',
- 'LIBPL': '/usr/local/lib/python3.3/config-3.3m',
- 'LIBRARY': 'libpython3.3m.a',
+ 'LIBPL': '/usr/local/lib/python3.4/config-3.4m',
+ 'LIBRARY': 'libpython3.4m.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lintl -lpthread  -lutil',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
  'LINKCC': 'c++ -pthread',
  'LINKFORSHARED': '-Wl,--export-dynamic',
+ 'LIPO_32BIT_FLAGS': '',
  'LN': 'ln',
  'LOCALMODLIBS': '',
  'LOG1P_DROPS_ZERO_SIGN': 0,
@@ -470,7 +500,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MACHDEPPATH': ':plat-openbsd5',
  'MACHDEPS': 'plat-openbsd5 @EXTRAPLATDIR@',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/local/lib/python3.3',
+ 'MACHDESTLIB': '/usr/local/lib/python3.4',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'c++ -pthread',
  'MAJOR_IN_MKDEV': 0,
@@ -479,7 +509,18 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MANDIR': '/usr/local/man',
  'MKDIR_P': 'mkdir -p',
  'MODLIBS': '',
- 'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  Modules/posixmodule.o  Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  Modules/_weakref.o  Modules/_functoolsmodule.o  Modules/operator.o  Modules/_collectionsmodule.o  Modules/itertoolsmodule.o  Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o Modules/textio.o Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  Modules/symtablemodule.o  Modules/xxsubtype.o',
+ 'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  '
+            'Modules/posixmodule.o  Modules/errnomodule.o  '
+            'Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  '
+            'Modules/_weakref.o  Modules/_functoolsmodule.o  '
+            'Modules/_operator.o  Modules/_collectionsmodule.o  '
+            'Modules/itertoolsmodule.o  Modules/atexitmodule.o  '
+            'Modules/_stat.o  Modules/_localemodule.o  Modules/_iomodule.o '
+            'Modules/iobase.o Modules/fileio.o Modules/bytesio.o '
+            'Modules/bufferedio.o Modules/textio.o Modules/stringio.o  '
+            'Modules/zipimport.o  Modules/faulthandler.o  '
+            'Modules/_tracemalloc.o Modules/hashtable.o  '
+            'Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': '',
  'MVWDELCH_IS_EXPRESSION': 1,
@@ -521,20 +562,25 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHON_FOR_BUILD': './python -E',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -DNDEBUG -O2 -pipe  -fPIC -O2 -pipe -O2 -pipe',
- 'PY_CORE_CFLAGS': '-fno-strict-aliasing -DNDEBUG -O2 -pipe  -fPIC -O2 -pipe -O2 -pipe -I. -IInclude -I./Include -I/usr/local/include -fPIC -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-fno-strict-aliasing -Werror=declaration-after-statement '
+              '-DNDEBUG -O2 -pipe  -fPIC -O2 -pipe -O2 -pipe',
+ 'PY_CORE_CFLAGS': '-fno-strict-aliasing -Werror=declaration-after-statement '
+                   '-DNDEBUG -O2 -pipe  -fPIC -O2 -pipe -O2 -pipe -I. '
+                   '-IInclude -I./Include -I/usr/local/include -fPIC '
+                   '-DPy_BUILD_CORE',
  'PY_CPPFLAGS': '-I. -IInclude -I./Include -I/usr/local/include',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.3.5/Python-3.3.5',
+ 'PY_LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.4.1/Python-3.4.1',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
+ 'Py_HASH_ALGORITHM': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
  'RANLIB': 'ranlib',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.3.5/Python-3.3.5:',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.4.1/Python-3.4.1',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '',
@@ -548,25 +594,25 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 8,
- 'SIZEOF_LONG_DOUBLE': 16,
+ 'SIZEOF_LONG': 4,
+ 'SIZEOF_LONG_DOUBLE': 8,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
- 'SIZEOF_PTHREAD_T': 8,
+ 'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 8,
+ 'SIZEOF_SIZE_T': 4,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 8,
- 'SIZEOF_VOID_P': 8,
+ 'SIZEOF_UINTPTR_T': 4,
+ 'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SO': '.so',
- 'SOABI': 'cpython-33m',
+ 'SOABI': 'cpython-34m',
  'SRCDIRS': 'Parser Grammar Objects Python Modules Mac',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
+ 'STRIPFLAG': '-s',
  'SUBDIRS': '',
  'SUBDIRSTOO': 'Include Lib Misc',
  'SYSLIBS': '-lm',
@@ -576,20 +622,22 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.3.5/Python-3.3.5: ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.4.1/Python-3.4.1 '
+               './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.3.5/Python-3.3.5: ./python ./Tools/scripts/run_tests.py',
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.4.1/Python-3.4.1 '
+               './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 3600,
  'THREADOBJ': 'Python/thread.o',
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
- 'UNICODE_DEPS': '\\ \\',
+ 'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'USE_COMPUTED_GOTOS': 0,
  'USE_INLINE': 1,
- 'VA_LIST_IS_ARRAY': 0,
- 'VERSION': '3.3',
+ 'VA_LIST_IS_ARRAY': 1,
+ 'VERSION': '3.4',
  'WANT_SIGFPE_HANDLER': 1,
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DOC_STRINGS': 1,
@@ -602,8 +650,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/obj/ports/Python-3.3.5/Python-3.3.5',
- 'abs_srcdir': '/usr/obj/ports/Python-3.3.5/Python-3.3.5',
+ 'abs_builddir': '/usr/obj/ports/Python-3.4.1/Python-3.4.1',
+ 'abs_srcdir': '/usr/obj/ports/Python-3.4.1/Python-3.4.1',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
